@@ -1,14 +1,17 @@
+import fnmatch
+import math
 import multiprocessing
 import os
-import fnmatch
+from functools import partial
+import typing
+
+import noisereduce
 import numpy as np
 from numpy.core.defchararray import array
 from pydub import AudioSegment
 from pydub.exceptions import CouldntDecodeError
-import math
-from audalign.fingerprint import DEFAULT_FS
-import noisereduce
-from functools import partial
+
+from audalign.config import BaseConfig
 
 cant_write_ext = [".mov", ".mp4", ".m4a"]
 cant_read_ext = [".txt", ".md", ".pkf", ".py", ".pyc"]
@@ -45,14 +48,17 @@ def find_files(path, extensions=["*"]):
         for extension in extensions:
             for f in fnmatch.filter(files, "*.%s" % extension):
                 p = os.path.join(dirpath, f)
-                yield (p, extension)
+                yield (p, os.path.splitext(p)[1])
 
 
 def create_audiosegment(
-    filepath: str, start_end: tuple = None, sample_rate=DEFAULT_FS, length=None
+    filepath: str,
+    start_end: tuple = None,
+    sample_rate=BaseConfig.sample_rate,
+    length=None,
 ) -> AudioSegment:
     if sample_rate is None:
-        sample_rate = DEFAULT_FS
+        sample_rate = BaseConfig.sample_rate
     if os.path.splitext(filepath)[1] in [".txt", ".json"]:
         raise CouldntDecodeError
     if len(filepath) > 0:
@@ -114,27 +120,32 @@ def get_audio_files_directory(directory_path: str, full_path: bool = False) -> l
         list: of all paths in file that are audio
     """
     aud_list = []
-    for file_path, _ in find_files(directory_path):
-        ext = os.path.splitext(file_path)[1]
-        try:
-            if ext in [".txt", ".json"] or ext in cant_read_ext:
-                continue
-            elif ext.lower() not in can_read_ext:
-                AudioSegment.from_file(file_path)
+    for file_path, ext in find_files(directory_path):
+        if check_is_audio_file(file_path=file_path):
             if full_path is False:
                 aud_list += [os.path.basename(file_path)]
             else:
                 aud_list += [file_path]
-        except CouldntDecodeError:
-            pass  # Do nothing
     return aud_list
 
 
+def check_is_audio_file(file_path: str) -> bool:
+    ext = os.path.splitext(file_path)[1]
+    try:
+        if ext in [".txt", ".json"] or ext in cant_read_ext:
+            return False
+        elif ext.lower() not in can_read_ext:
+            AudioSegment.from_file(file_path)
+    except CouldntDecodeError:
+        return False
+    return True
+
+
 def read(
     filename: str,
     wrdestination=None,
     start_end: tuple = None,
-    sample_rate=DEFAULT_FS,
+    sample_rate=BaseConfig.sample_rate,
 ):
     """
     Reads any file supported by pydub (ffmpeg) and returns a numpy array and the bit depth
@@ -186,17 +197,22 @@ def noise_remove(
     verbose=False,
     **kwargs,
 ):
-
     audiofile = create_audiosegment(filepath)
     new_data = _floatify_data(audiofile)
 
     if not alt_noise_filepath:
-        noisy_part = new_data[(noise_start * DEFAULT_FS) : (noise_end * DEFAULT_FS)]
+        noisy_part = new_data[
+            (noise_start * BaseConfig.sample_rate) : (
+                noise_end * BaseConfig.sample_rate
+            )
+        ]
     else:
         noise_audiofile = create_audiosegment(alt_noise_filepath)
         noise_new_data = _floatify_data(noise_audiofile)
         noisy_part = noise_new_data[
-            (noise_start * DEFAULT_FS) : (noise_end * DEFAULT_FS)
+            (noise_start * BaseConfig.sample_rate) : (
+                noise_end * BaseConfig.sample_rate
+            )
         ]
 
     print(f"Reducing noise: {filepath}")
@@ -243,7 +259,7 @@ def noise_remove_directory(
     **kwargs,
 ):
     noise_data = _floatify_data(create_audiosegment(noise_filepath))[
-        (noise_start * DEFAULT_FS) : (noise_end * DEFAULT_FS)
+        (noise_start * BaseConfig.sample_rate) : (noise_end * BaseConfig.sample_rate)
     ]
     file_names = []
     for file_path, _ in find_files(directory):
@@ -413,7 +429,7 @@ def _uniform_level(
         print(f"Uniform Leveling: {file_path}")
         audiofile = create_audiosegment(file_path)
         audiofile_data = np.frombuffer(audiofile._data, np.int16)
-        width *= DEFAULT_FS
+        width *= BaseConfig.sample_rate
         if width > len(audiofile_data):
             width = len(audiofile_data)
         index_list = calc_array_indexes(
@@ -473,7 +489,9 @@ def level_by_normalize(
     audiofile_data, index_list, overlap_array, width, exclude_min_db
 ):
     new_audio_data = np.zeros(len(audiofile_data), dtype=np.float32)
-    silent_audiosegment = create_audiosegment("", length=width / DEFAULT_FS * 1000)
+    silent_audiosegment = create_audiosegment(
+        "", length=width / BaseConfig.sample_rate * 1000
+    )
     for index in index_list:
         silent_audiosegment._data = audiofile_data[index : index + width]
         if silent_audiosegment.max_dBFS < exclude_min_db:
@@ -488,7 +506,9 @@ def level_by_normalize(
 
 def level_by_ave(audiofile_data, index_list, overlap_array, width, exclude_min_db):
     new_audio_data = np.zeros(len(audiofile_data), dtype=np.float32)
-    audiosegment_slicer = create_audiosegment("", length=width / DEFAULT_FS * 1000)
+    audiosegment_slicer = create_audiosegment(
+        "", length=width / BaseConfig.sample_rate * 1000
+    )
     average_level_list = []
 
     for index in index_list:
@@ -513,6 +533,9 @@ def level_by_ave(audiofile_data, index_list, overlap_array, width, exclude_min_d
 def shift_get_files(results: dict, sample_rate: int = None):
     names_and_paths = results.pop("names_and_paths")
     temp_a = results.pop("match_info")
+    temp_rankings = None
+    if results.get("rankings") is not None:
+        temp_rankings = results.pop("rankings")
 
     shifts_files = _shift_files(
         results,
@@ -524,6 +547,8 @@ def shift_get_files(results: dict, sample_rate: int = None):
     )
     results["names_and_paths"] = names_and_paths
     results["match_info"] = temp_a
+    if temp_rankings is not None:
+        results["rankings"] = temp_rankings
     return shifts_files
 
 
@@ -544,14 +569,14 @@ def shift_write_files(
 
 def _shift_files(
     files_shifts: dict,
-    destination_path: str,
+    destination_path: typing.Optional[str],
     names_and_paths: dict,
-    write_extension: str,
+    write_extension: typing.Optional[str],
     sample_rate: int = None,
     return_files: bool = False,
 ):
     if sample_rate is None:
-        sample_rate = DEFAULT_FS
+        sample_rate = BaseConfig.sample_rate
 
     if write_extension:
         if write_extension[0] != ".":
@@ -635,8 +660,9 @@ def _shift_files(
 
 
 def shift_write_file(file_path, destination_path, offset_seconds):
-
-    silence = AudioSegment.silent(offset_seconds * 1000, frame_rate=DEFAULT_FS)
+    silence = AudioSegment.silent(
+        offset_seconds * 1000, frame_rate=BaseConfig.sample_rate
+    )
 
     audiofile = create_audiosegment(file_path)
     audiofile = silence + audiofile
@@ -645,9 +671,11 @@ def shift_write_file(file_path, destination_path, offset_seconds):
         audiofile.export(file_place, format=os.path.splitext(destination_path)[1][1:])
 
 
-def get_shifted_file(file_path, offset_seconds, sample_rate=DEFAULT_FS) -> np.array:
+def get_shifted_file(
+    file_path, offset_seconds, sample_rate=BaseConfig.sample_rate
+) -> np.array:
     silence = AudioSegment.silent(offset_seconds * 1000, frame_rate=sample_rate)
 
     audiofile = create_audiosegment(file_path, sample_rate=sample_rate)
     audiofile = silence + audiofile
-    return np.frombuffer(audiofile._data, np.int16)
\ No newline at end of file
+    return np.frombuffer(audiofile._data, np.int16)
